package com.tanpu.feo.feojob.jobs;

import cn.hutool.core.bean.BeanUtil;
import cn.hutool.core.util.ObjectUtil;
import cn.hutool.core.util.StrUtil;
import cn.hutool.crypto.digest.MD5;
import cn.hutool.json.JSONUtil;
import com.tanpu.feo.feojob.entity.*;
import com.tanpu.feo.feojob.jobs.dto.WorkDataDto;
import com.tanpu.feo.feojob.jobs.dto.WxCpDepartDto;
import com.tanpu.feo.feojob.jobs.service.OrgSyncByWxcpService;
import com.tanpu.feo.feojob.service.*;
import lombok.extern.slf4j.Slf4j;
import me.chanjar.weixin.common.error.WxErrorException;
import me.chanjar.weixin.cp.api.WxCpService;
import me.chanjar.weixin.cp.api.impl.WxCpServiceImpl;
import me.chanjar.weixin.cp.bean.Gender;
import me.chanjar.weixin.cp.bean.WxCpDepart;
import me.chanjar.weixin.cp.bean.WxCpUser;
import me.chanjar.weixin.cp.config.impl.WxCpDefaultConfigImpl;
import org.springframework.scheduling.annotation.Scheduled;
import org.springframework.stereotype.Component;

import javax.annotation.Resource;
import java.util.*;

/**
 * @author zejia zj wu
 * @date 20210518
 * @Description 从企业微信 同步 组织信息 及 员工信息
 */
@Component
@Slf4j
public class OrgSyncByWxcpJob {

    final static String keyStr = "{\"corpId\":\"ww08675a3a48c9e8a2\",\"agentId\":\"1000006\",\"corpSecret\":\"VNh2sdxSOPJ0wcHVoWWUrcCjXFXPsxOs12KkAogyCQI\",\"token\":\"jyzyceshi888\",\"aesKey\":\"wHkEDvDLOM8xqiuGn0VCeN9rtJWgeaQ12cxKpcmWsSS\",\"sendMessageAppId\":\"wxe177c62fa1e1c602\"}\n";

    @Resource
    private OrgExtService orgExtService;
    @Resource
    private OrgService orgService;
    @Resource
    private UserInfoService userInfoService;
    @Resource
    private DepartmentService departmentService;
    @Resource
    private DepartmentEmployeeService departmentEmployeeService;
    @Resource
    private EmployeeService employeeService;
    @Resource
    private EmployeeRoleService employeeRoleService;
    @Resource
    private RoleService roleService;
    @Resource
    private OrgSyncByWxcpService orgSyncByWxcpService;
    @Resource
    private IfaAssetsService ifaAssetsService;

    @Scheduled(cron="0 30 2 * * ?")   //每日凌晨2点30执行
    public void execute(){
        log.info("====== 开始执行OrgSyncByWxcpJob ======");
        try {
            orgSyncByWxcp("Y");
        } catch (Exception e) {
            log.error("====== 异常结束执行OrgSyncByWxcpJob，错误：{}=======", e.getMessage());
        }
        log.info("====== 结束执行OrgSyncByWxcpJob ======");
    }

    /**
     * 执行 部门 及 员工 同步任务
     * @param isAuto 任务触发类型 Y 定时任务 / N 手动
     */
    public void orgSyncByWxcp(String isAuto) {
        // 1 扫描 org_ext 表 获取需要 执行同步的 机构
        List<OrgExt> orgExtList = orgExtService.findOrgExtByAyto();
        for (OrgExt orgExt : orgExtList) {
            String orgId = orgExt.getOrgId();
            log.info("======开始同步机构：{} 的信息======", orgId);

            //2  根据orgId 查找机构 相关信息
            Org org = orgService.findById(orgId);

            //3 从企业微信获取组织信息及员工信息
            WxCpDefaultConfigImpl wxCpDefaultConfig = JSONUtil.toBean(orgExt.getJsonWxcpKey(), WxCpDefaultConfigImpl.class);

            List<WxCpDepart> wxCpDepartList; // 机构信息
            List<WxCpDepartDto> wxCpDepartDtoList;//自定义的 部门信息
            try {
                wxCpDepartList = getWxCpDepartList(wxCpDefaultConfig);
                wxCpDepartDtoList = getWxCpUserList(wxCpDepartList,wxCpDefaultConfig);
            } catch (Exception e) {
                log.info("======同步失败->机构：{} -> 错误信息-> {}======", orgId, e.getMessage());
                continue;
            }

            //4 判断是否需要 同步
            String digestHex = isExecute(isAuto, wxCpDepartDtoList, orgExt.getMd5WxcpData());
            if (StrUtil.isBlank(digestHex)) {
                log.info("====== 机构:{} 不需要执行同步=======", orgId);
                continue;
            }

            //5 开始比对 5张表 数据 user_info employee department department_employee employee_role
            String corpId = wxCpDefaultConfig.getCorpId();
            WorkDataDto<UserInfo> workUserInfo = userInfoWork(org.getId(), wxCpDepartDtoList, corpId);
            WorkDataDto<Employee> workEmployee = employeeWork(org.getId(), wxCpDepartDtoList, corpId);
            WorkDataDto<Department> workDepartment = departmentWork(org.getId(), wxCpDepartDtoList);
            WorkDataDto<DepartmentEmployee> workDepartmentEmployee = departmentEmployeeWork(org.getId(), wxCpDepartDtoList, corpId);
            WorkDataDto<EmployeeRole> workEmployeeRole = employeeRoleWork(org.getId(), wxCpDepartDtoList, corpId);

            //6 删除列表中 管理员 用户信息
            deleteAdmin(orgId, workUserInfo, workEmployee, workEmployeeRole);

            log.info("==================================");
            log.info(JSONUtil.toJsonStr(workUserInfo));
            log.info("==================================");
            log.info(JSONUtil.toJsonStr(workEmployee));
            log.info("==================================");
            log.info(JSONUtil.toJsonStr(workDepartment));
            log.info("==================================");
            log.info(JSONUtil.toJsonStr(workDepartmentEmployee));
            log.info("==================================");
            log.info(JSONUtil.toJsonStr(workEmployeeRole));
            log.info("==================================");

            //6 执行 增删改
            List<IfaAssets> execute = orgSyncByWxcpService.execute(workUserInfo, workEmployee, workDepartment, workDepartmentEmployee, workEmployeeRole);
            for (IfaAssets ifaAssets : execute) {
                try {
                    ifaAssetsService.insertIfaAssets(ifaAssets);
                } catch (Exception e) {
                    log.info("======往ifaAssets写数据错误->机构：{} -> 错误信息-> {}======", orgId, e.getMessage());
                }
            }
            //7 讲最新的md5值 存至 orgExt 表中
            orgExt.setMd5WxcpData(digestHex);
            orgExtService.updataById(orgExt);
        }

    }

    private void deleteAdmin(String orgId, WorkDataDto<UserInfo> workUserInfo, WorkDataDto<Employee> workEmployee, WorkDataDto<EmployeeRole> workEmployeeRole) {
        // 获取 role
        Map<String, String> roleMap =roleService.findInfoNoAdmin();
        // 获取 admin 的员工id
        List<String> employeeIdList =  employeeRoleService.findInfoByOrgIdAndAdmin(orgId, roleMap.get("m"));
        List<UserInfo> deleteList1 = workUserInfo.getDeleteList();
        Iterator<UserInfo> iterator1 = deleteList1.iterator();
        while (iterator1.hasNext()) {
            UserInfo userInfo = iterator1.next();
            for (String s : employeeIdList) {
                if (s.equals(userInfo.getId())) {
                    iterator1.remove();
                }
            }
        }

        List<Employee> deleteList2 = workEmployee.getDeleteList();
        Iterator<Employee> iterator2 = deleteList2.iterator();
        while (iterator2.hasNext()) {
            Employee employee = iterator2.next();
            for (String s : employeeIdList) {
                if (s.equals(employee.getEmployeeId())) {
                    iterator2.remove();
                }
            }
        }

        List<EmployeeRole> deleteList3 = workEmployeeRole.getDeleteList();
        Iterator<EmployeeRole> iterator3 = deleteList3.iterator();
        while (iterator3.hasNext()) {
            EmployeeRole employeeRole = iterator3.next();
            for (String s : employeeIdList) {
                if (s.equals(employeeRole.getEmployeeId())) {
                    iterator3.remove();
                }
            }
        }


    }

    private WorkDataDto<EmployeeRole> employeeRoleWork(String orgId, List<WxCpDepartDto> wxCpDepartDtoList, String corpId) {
        WorkDataDto<EmployeeRole> workDataDto = new WorkDataDto<>();
        List<EmployeeRole> insertList = new ArrayList<>();
        List<EmployeeRole> deleteList = new ArrayList<>();
        List<EmployeeRole> updateList = new ArrayList<>();
        //获取 数据库 部门员工关系 信息
        List<EmployeeRole> employeeRoleList = employeeRoleService.findInfoByOrgId(orgId);
        // 获取 role
        Map<String, String> roleMap =roleService.findInfoNoAdmin();
        // 预处理 新数据
        HashMap<String, WxCpUser> hashMap = new HashMap<>();
        for (WxCpDepartDto wxCpDepartDto : wxCpDepartDtoList) {
            List<WxCpUser> wxCpUserList = wxCpDepartDto.getWxCpUserList();
            for (WxCpUser wxCpUser : wxCpUserList) {
                // key employee_id + '&' + role_id
                String type = wxCpUser.getIsLeader() == 1 ? "t" : "i";
                hashMap.put(corpId + "_" + wxCpUser.getUserId() + "&" + roleMap.get(type), wxCpUser);
            }
        }
        for (EmployeeRole employeeRole : employeeRoleList) {
            String employeeId = employeeRole.getEmployeeId();
            String roleId = employeeRole.getRoleId();
            String key = employeeId + "&" + roleId;
            WxCpUser wxCpUser = hashMap.get(key);
            //删除
            if (ObjectUtil.isNull(wxCpUser)) {
                // 删除
                deleteList.add(employeeRole);
                continue;
            }
            // 员工 角色关联关系没有 更新
            hashMap.remove(key);
        }
        for (String key : hashMap.keySet()) {
            String[] split = key.split("&");
            String employeeId = split[0];
            String roleId = split[1];
            EmployeeRole employeeRole = new EmployeeRole();
            employeeRole.setEmployeeId(employeeId);
            employeeRole.setRoleId(roleId);
            employeeRole.setOrgId(orgId);
            insertList.add(employeeRole);
        }
        workDataDto.setDeleteList(deleteList);
        workDataDto.setInsertList(insertList);
        workDataDto.setUpdateList(updateList);
        return  workDataDto;

    }

    private WorkDataDto<DepartmentEmployee> departmentEmployeeWork(String orgId, List<WxCpDepartDto> wxCpDepartDtoList, String corpId) {
        WorkDataDto<DepartmentEmployee> workDataDto = new WorkDataDto<>();
        List<DepartmentEmployee> insertList = new ArrayList<>();
        List<DepartmentEmployee> deleteList = new ArrayList<>();
        List<DepartmentEmployee> updateList = new ArrayList<>();
        //获取 数据库 部门员工关系 信息
        List<DepartmentEmployee> departmentEmployeeList = departmentEmployeeService.findInfoByOrgId(orgId);
        // 预处理 新数据
        HashMap<String, WxCpUser> hashMap = new HashMap<>();
        for (WxCpDepartDto wxCpDepartDto : wxCpDepartDtoList) {
            List<WxCpUser> wxCpUserList = wxCpDepartDto.getWxCpUserList();
            for (WxCpUser wxCpUser : wxCpUserList) {
                // key department_id + '&' + employee_id
                hashMap.put(orgId + "_" + wxCpDepartDto.getId()+ "&" + corpId + "_" + wxCpUser.getUserId(), wxCpUser);

            }
        }
        for (DepartmentEmployee departmentEmployee : departmentEmployeeList) {
            String departmentId = departmentEmployee.getDepartmentId();
            String employeeId = departmentEmployee.getEmployeeId();
            String key = departmentId + "&" + employeeId;
            WxCpUser wxCpUser = hashMap.get(key);
            if (ObjectUtil.isNull(wxCpUser)) {
                // 删除
                deleteList.add(departmentEmployee);
                continue;
            }
            //更新
            String type = wxCpUser.getIsLeader() == 1 ? "d" : "s";
            if (!departmentEmployee.getType().equals(type)) {
                departmentEmployee.setType(type);
                updateList.add(departmentEmployee);
            }
            hashMap.remove(key);
        }
        for (String s : hashMap.keySet()) {
            WxCpUser wxCpUser = hashMap.get(s);
            String type = wxCpUser.getIsLeader() == 1 ? "d" : "s";
            String[] split = s.split("&");
            String departmentId = split[0];
            String employeeId = split[1];
            DepartmentEmployee departmentEmployee = new DepartmentEmployee();
            departmentEmployee.setEmployeeId(employeeId);
            departmentEmployee.setDepartmentId(departmentId);
            departmentEmployee.setType(type);
            departmentEmployee.setOrgId(orgId);
            insertList.add(departmentEmployee);
        }
        workDataDto.setDeleteList(deleteList);
        workDataDto.setInsertList(insertList);
        workDataDto.setUpdateList(updateList);
        return  workDataDto;
    }

    private WorkDataDto<Department> departmentWork(String orgId, List<WxCpDepartDto> wxCpDepartDtoList) {
        WorkDataDto<Department> workDataDto = new WorkDataDto<>();
        List<Department> insertList = new ArrayList<>();
        List<Department> deleteList = new ArrayList<>();
        List<Department> updateList = new ArrayList<>();
        //获取 数据库 部门 信息
        List<Department> departmentList = departmentService.findDepartmentByOrgId(orgId);
        // 预处理 新数据
        HashMap<String, WxCpDepartDto> hashMap = new HashMap<>();
        HashMap<Long, WxCpDepartDto> hashMap2 = new HashMap<>();
        for (WxCpDepartDto wxCpDepartDto : wxCpDepartDtoList) {
            hashMap.put(orgId + "_" + wxCpDepartDto.getId(), wxCpDepartDto);
            hashMap2.put(wxCpDepartDto.getId(), wxCpDepartDto);
        }
        for (Department department : departmentList) {
            String departmentId = department.getDepartmentId();
            WxCpDepartDto wxCpDepartDto = hashMap.get(departmentId);
            //删除
            if (ObjectUtil.isNull(wxCpDepartDto)) {
                deleteList.add(department);
                continue;
            }
            //更新
            Long parentId1 = wxCpDepartDto.getParentId();
            String parentId = parentId1 == 1 ? null :orgId + "_" + parentId1;
            if (!department.getDepartmentName().equals(wxCpDepartDto.getName()) || StrUtil.compareIgnoreCase(department.getParentDepartId(), parentId, false) != 0
            || !department.getMembers().equals(wxCpDepartDto.getMembers())) {
                department.setDepartmentName(wxCpDepartDto.getName());
                department.setParentDepartId(parentId);
                department.setMembers(wxCpDepartDto.getMembers());
                updateList.add(department);
            }
            hashMap.remove(departmentId);
        }
        //修改
        for (String departmentId : hashMap.keySet()) {
            WxCpDepartDto wxCpDepartDto = hashMap.get(departmentId);
            Long parentId1 = wxCpDepartDto.getParentId();
            String parentId = parentId1 == 1 ? null :orgId + "_" + parentId1;
            Department department = new Department();
            department.setDepartmentId(orgId + "_" + wxCpDepartDto.getId());
            department.setParentDepartId(parentId);
            department.setDepartmentName(wxCpDepartDto.getName());
            department.setLevel(getLevel(hashMap2, wxCpDepartDto.getId()));
            department.setMembers(wxCpDepartDto.getMembers());
            department.setOrgId(orgId);
            insertList.add(department);
        }
        workDataDto.setDeleteList(deleteList);
        workDataDto.setInsertList(insertList);
        workDataDto.setUpdateList(updateList);
        return  workDataDto;
    }

    private Integer getLevel(HashMap<Long, WxCpDepartDto> hashMap2, Long id) {
        if (hashMap2.get(id).getParentId() == 1) {
            return 1;
        }
        return  1 + getLevel(hashMap2, hashMap2.get(id).getParentId());
    }

    private WorkDataDto<Employee> employeeWork(String orgId, List<WxCpDepartDto> wxCpDepartDtoList, String corpId) {
        WorkDataDto<Employee> workDataDto = new WorkDataDto<>();
        List<Employee> insertList = new ArrayList<>();
        List<Employee> deleteList = new ArrayList<>();
        List<Employee> updateList = new ArrayList<>();
        //获取 数据库 员工 信息
        List<Employee> employeeList = employeeService.getEmployeeSListByOrgId(orgId);

        // 预处理 新数据
        HashMap<String, WxCpUser> hashMap = new HashMap<>();
        for (WxCpDepartDto wxCpDepartDto : wxCpDepartDtoList) {
            List<WxCpUser> wxCpUserList = wxCpDepartDto.getWxCpUserList();
            for (WxCpUser wxCpUser : wxCpUserList) {
                hashMap.put(corpId + "_" + wxCpUser.getUserId(), wxCpUser);
            }
        }

        // 计算 变化数据
        for (Employee employee : employeeList) {
            String employeeId = employee.getEmployeeId();
            WxCpUser wxCpUser = hashMap.get(employeeId);
            //删除
            if (ObjectUtil.isNull(wxCpUser)) {
                deleteList.add(employee);
                continue;
            }
            //更新
            String status = wxCpUser.getStatus() == 1 ? "on" : "off";
            if (!employee.getName().equals(wxCpUser.getName()) || !employee.getMail().equals(wxCpUser.getEmail()) ||
                    StrUtil.isBlank(employee.getBoundWechat()) || !employee.getStatus().equals(status)) {
                employee.setName(wxCpUser.getName());
                employee.setMail(wxCpUser.getEmail());
                if (StrUtil.isBlankIfStr(employee.getBoundWechat())) {
                    employee.setBoundWechat(orgId + "_" + wxCpUser.getUserId());
                }
                employee.setStatus(status);
                updateList.add(employee);
            }
            hashMap.remove(employeeId);
        }
        //修改
        for (String key : hashMap.keySet()) {
            WxCpUser wxCpUser = hashMap.get(key);
            Employee employee = new Employee();
            employee.setEmployeeId(corpId + "_" + wxCpUser.getUserId());
            employee.setName(wxCpUser.getName());
            employee.setPhone(wxCpUser.getMobile());
            employee.setMail(wxCpUser.getEmail());
            employee.setNumber(null);
            employee.setOrgId(orgId);
            employee.setBoundWechat(orgId + "_" + wxCpUser.getUserId());
            employee.setStatus(wxCpUser.getStatus() == 1 ? "on" : "off");
            insertList.add(employee);
        }
        workDataDto.setDeleteList(deleteList);
        workDataDto.setInsertList(insertList);
        workDataDto.setUpdateList(updateList);
        return  workDataDto;
    }

    private WorkDataDto<UserInfo> userInfoWork(String orgId, List<WxCpDepartDto> wxCpDepartDtoList, String corpId) {
        WorkDataDto<UserInfo> workDataDto = new WorkDataDto<>();
        List<UserInfo> insertList = new ArrayList<>();
        List<UserInfo> deleteList = new ArrayList<>();
        List<UserInfo> updateList = new ArrayList<>();
        //获取 数据库用户信息
        List<UserInfo> userInfoList = userInfoService.getUserInfoListByOrgId(orgId);

        // 预处理 新数据
        HashMap<String, WxCpUser> hashMap = new HashMap<>();
        for (WxCpDepartDto wxCpDepartDto : wxCpDepartDtoList) {
            List<WxCpUser> wxCpUserList = wxCpDepartDto.getWxCpUserList();
            for (WxCpUser wxCpUser : wxCpUserList) {
                hashMap.put(corpId + "_" + wxCpUser.getUserId(), wxCpUser);
            }
        }


        // 计算 变化数据
        for (UserInfo userInfo : userInfoList) {
            String id = userInfo.getId();
            WxCpUser wxCpUser = hashMap.get(id);
            // 删除
            if (ObjectUtil.isNull(wxCpUser)) {
                deleteList.add(userInfo);
                continue;
            }
            // 更新
            if (!userInfo.getUiUsername().equals(wxCpUser.getName()) || StrUtil.isBlankIfStr(userInfo.getUiHeadimgMp()) || !wxCpUser.getUserId().equals(userInfo.getWxcpUid())) {
                userInfo.setUiUsername(wxCpUser.getName());
                userInfo.setUiHeadimgMp(wxCpUser.getThumbAvatar());
                userInfo.setWxcpUid(wxCpUser.getUserId());
                updateList.add(userInfo);
            }
            hashMap.remove(id);
        }
        for (String key : hashMap.keySet()) {
            // todo
            WxCpUser wxCpUser = hashMap.get(key);
            UserInfo userInfo = new UserInfo();
            userInfo.setUiTelphone(wxCpUser.getMobile());
            userInfo.setUiUsername(wxCpUser.getName());
            Gender gender = wxCpUser.getGender();
            String sex = gender.getCode().equals("1") ? "0" : "1";
            userInfo.setUiSex(sex);
            userInfo.setUiHeadimg(wxCpUser.getThumbAvatar());
            userInfo.setUiHeadimgMp(wxCpUser.getThumbAvatar());
            userInfo.setCreateby("SYS");//setCreateby(creator);
            userInfo.setCreatetime((new Date()));
            userInfo.setOrgId(orgId);
//            userInfo.setId(employeeId);
            userInfo.setId(corpId + "_" + wxCpUser.getUserId());
            userInfo.setUiMobilephoneMp(wxCpUser.getMobile());
            userInfo.setDeletetag("0");
            userInfo.setUiShenfen("0");
            userInfo.setUiEmailMp(wxCpUser.getEmail());
            String nickName = wxCpUser.getName();
            userInfo.setUiUsername(nickName);
            userInfo.setUiUsernameMp(nickName);
            userInfo.setUiRzstatus(0);
            //默认小名片 0：小名片 1：大名片
            userInfo.setUiTypeMp("1");
            userInfo.setLevel(2);
            // 0： 白银  1：黄金  2：钻石
            userInfo.setUiGrade("0");
            userInfo.setUiSource("pc");
            userInfo.setUiRegisterTime(userInfo.getCreatetime());
            userInfo.setUiChannel(null);
            userInfo.setWxcpUid(wxCpUser.getUserId());
            insertList.add(userInfo);
        }
        workDataDto.setDeleteList(deleteList);
        workDataDto.setInsertList(insertList);
        workDataDto.setUpdateList(updateList);
        return  workDataDto;
    }

    private String isExecute(String isAuto, List<WxCpDepartDto> wxCpDepartDtoList, String md5WxcpData) {
        String digestHex = MD5.create().digestHex(JSONUtil.toJsonStr(wxCpDepartDtoList));
        if (!"Y".equals(isAuto)) {
            return digestHex;
        }
        if (digestHex.equals(md5WxcpData)){
            return null;
        }
        return digestHex;
    }

    private List<WxCpDepartDto> getWxCpUserList(List<WxCpDepart> wxCpDepartList, WxCpDefaultConfigImpl wxCpDefaultConfig) throws Exception {
        WxCpService cpService = new WxCpServiceImpl();
        cpService.setWxCpConfigStorage(wxCpDefaultConfig);
        ArrayList<WxCpDepartDto> wxCpDepartDtoArrayList = new ArrayList<>();
        for (WxCpDepart wxCpDepart : wxCpDepartList) {
            try {
                List<WxCpUser> wxCpUsers = cpService.getUserService().listByDepartment(wxCpDepart.getId(), Boolean.FALSE, 0);
                WxCpDepartDto wxCpDepartDto = new WxCpDepartDto();
                BeanUtil.copyProperties(wxCpDepart, wxCpDepartDto, true);
                wxCpDepartDto.setWxCpUserList(wxCpUsers);
                wxCpDepartDto.setMembers(wxCpUsers.size());
                wxCpDepartDtoArrayList.add(wxCpDepartDto);
            } catch (WxErrorException e) {
                log.error("======根据企业微信key 获取企业微信员工信息调用失败，错误：{}=======", e.getMessage());
                throw new Exception("根据企业微信key 获取企业微信组织结构调用失败");
            }
        }
        return wxCpDepartDtoArrayList;
    }

    private List<WxCpDepart> getWxCpDepartList(WxCpDefaultConfigImpl wxCpDefaultConfig) throws Exception {
        WxCpService cpService = new WxCpServiceImpl();
        cpService.setWxCpConfigStorage(wxCpDefaultConfig);
        List<WxCpDepart> wxCpDeparts;
        try {
            wxCpDeparts = cpService.getDepartmentService().list(null);
        } catch (WxErrorException e) {
            log.error("======根据企业微信key 获取企业微信组织结构调用失败，错误：{}=======", e.getMessage());
            throw new Exception("根据企业微信key 获取企业微信组织结构调用失败");
        }
        return wxCpDeparts;
    }

    public static void main(String[] args) throws Exception {
        OrgSyncByWxcpJob orgSyncByWxcpJob = new OrgSyncByWxcpJob();
        WxCpDefaultConfigImpl wxCpDefaultConfig = JSONUtil.toBean(keyStr, WxCpDefaultConfigImpl.class);

        List<WxCpDepart> wxCpDepartList = orgSyncByWxcpJob.getWxCpDepartList(wxCpDefaultConfig); // 机构信息
        List<WxCpDepartDto> wxCpDepartDtoList = orgSyncByWxcpJob.getWxCpUserList(wxCpDepartList,wxCpDefaultConfig);
        log.info("=========================");
//        log.info(JSONUtil.toJsonStr(wxCpDepartDtoList));

        String digestHex = MD5.create().digestHex(JSONUtil.toJsonStr(wxCpDepartDtoList));
        log.info(digestHex);
    }

}
